Improve this doc View Source

Use `$httpProvider` to change the default behavior of the $http service.

## Properties

- ### `defaults`

  | Object containing default values for all $http requests. `defaults.xsrfCookieName` - {string} - Name of cookie containing the XSRF token. Defaults value is `'XSRF-TOKEN'`. `defaults.xsrfHeaderName` - {string} - Name of HTTP header to populate with the XSRF token. Defaults value is `'X-XSRF-TOKEN'`. `defaults.headers` - {Object} - Default headers for all $http requests. Refer to $http for documentation on setting default headers. `defaults.headers.common` `defaults.headers.post` `defaults.headers.put` `defaults.headers.patch`